unit CLET183;
{ unite de pilotage des alimentation COnvergies 3 sorties }
{ F. OTT, modifi le 27.10.99                             }

interface

uses gpib_CEC;

const
     Vmax1=18; { tension max sur channels 1 et 2 }
     Imax1=3; { courant max sur channels 1 et 2 }
     Vmax2=6; { tension max sur channels 3 }
     Imax2=5; { courant max sur channels 3 }

{ initialisation des alimentations }
Function Initialize_CLET183(adresse:byte):integer;
{ INPUT: adresse, adresse GPIB                         }
{ OUTPUT: met la sortie de l'alimenation en pos active }
{         integer, code d'erreur                       }
Function SwitchON_Clet183(adresse:byte):integer;
{ INPUT: adresse, adresse GPIB                         }
{ OUTPUT: met la sortie de l'alimenation en pos OFF    }
{         integer, code d'erreur                       }
Function SwitchOFF_Clet183(adresse:byte):integer;
{ INPUT: adresse, adresse GPIB                         }
{        valeur, valeur du courant en AMPERES          }
{ OUTPUT: real, valeur du courant                      }
Function GetCourant_CLET183(adresse:byte;channel:byte):real;
{ INPUT: adresse, adresse GPIB                         }
{        channel, selctionne le channel                }
{        valeur, valeur du courant en AMPERES          }
{ OUTPUT: integer, code d'erreur                       }
Function SetCourant_Clet183(adresse:byte;channel:byte;valeur:real):integer;
{ INPUT: adresse, adresse GPIB                         }
{        valeur, valeur du courant en AMPERES          }
{ OUTPUT: real, valeur du courant                      }
Function GetTension_CLET183(adresse:byte;channel:byte):real;
{ INPUT: adresse, adresse GPIB                         }
{        channel, selctionne le channel                }
{        valeur, valeur de la tension VOLTS            }
{ OUTPUT: integer, code d'erreur                       }
Function SetTension_Clet183(adresse:byte;channel:byte;valeur:real):integer;
{ passage en alim de tension }
{ INPUT: adresse, adresse GPIB                         }
{ OUTPUT: integer, code d'erreur                       }
{ REMARK: on coupe la sortie quand on switch dans ce mode }
Function SetToVoltageSource_CLET183(adresse:byte;channel:byte):integer;
{ passage en alim de courant }
{ INPUT: adresse, adresse GPIB                         }
{ OUTPUT: integer, code d'erreur                       }
{ REMARK: on coupe la sortie quand on switch dans ce mode }
Function SetToCurrentSource_CLET183(adresse:byte;channel:byte):integer;


implementation

{ initialisation des alimentations }
Function Initialize_CLET183(adresse:byte):integer;
begin
     { protection surintensit }
     GPIBSend(adresse,'SOUR:CURR:PROT:STAT 1');
{     GPIBSend(adresse,'STAT:OPER?',status);
     GPIBRead(s,255,length,adresse,status);
     writeln(s); donne un message obscur }
result:=0;
end;

{ INPUT: adresse, adresse GPIB                         }
{ OUTPUT: met la sortie de l'alimenation en pos active }
{         integer, code d'erreur                       }
Function SwitchON_Clet183(adresse:byte):integer; {ok }
begin
 GPIBsend(adresse,'OUTP:STAT 1');
result:=0;
end;

{ INPUT: adresse, adresse GPIB                         }
{ OUTPUT: met la sortie de l'alimenation en pos OFF    }
{         integer, code d'erreur                       }
Function SwitchOFF_Clet183(adresse:byte):integer;     {ok }
begin
 GPIBsend(adresse,'OUTP:STAT 0');
result:=0;
end;

{ INPUT: adresse, adresse GPIB                         }
{        valeur, valeur du courant en AMPERES          }
{ OUTPUT: real, valeur du courant                      }
Function GetCourant_CLET183(adresse:byte;channel:byte):real;
begin
result:=0;
end;

{ INPUT: adresse, adresse GPIB                         }
{        channel, selctionne le channel                }
{        valeur, valeur du courant en AMPERES          }
{ OUTPUT: integer, code d'erreur                       }
Function SetCourant_Clet183(adresse:byte;channel:byte;valeur:real):integer;
var s:string;
begin
     { selection du channel }
     str(channel,s);
     GPIBSend(adresse,'CHAN '+s);
     str(valeur,s);
     GPIBSend(adresse,'SOUR:CURR '+s);
result:=0;
end;

{ INPUT: adresse, adresse GPIB                         }
{        valeur, valeur du courant en AMPERES          }
{ OUTPUT: real, valeur du courant                      }
Function GetTension_CLET183(adresse:byte;channel:byte):real;
begin
result:=0;
end;

{ INPUT: adresse, adresse GPIB                         }
{        channel, selctionne le channel                }
{        valeur, valeur de la tension VOLTS            }
{ OUTPUT: integer, code d'erreur                       }
Function SetTension_Clet183(adresse:byte;channel:byte;valeur:real):integer;
var s:string;
begin
     { selection du channel }
     str(channel,s);
     GPIBSend(adresse,'CHAN '+s);
     str(valeur,s);
     { writeln(s); }
     GPIBSend(adresse,'SOUR:VOLT '+s);
result:=0;
end;

{ passage en alim de tension }
{ INPUT: adresse, adresse GPIB                         }
{ OUTPUT: integer, code d'erreur                       }
{ REMARK: on coupe la sortie quand on switch dans ce mode }
Function SetToVoltageSource_CLET183(adresse:byte;channel:byte):integer;
begin
     SwitchOFF_CLET183(adresse);
     SetTension_CLET183(adresse,channel,0);
     case channel of
          1:SetCourant_CLET183(adresse,channel,Imax1);
          2:SetCourant_CLET183(adresse,channel,Imax1);
          3:SetCourant_CLET183(adresse,channel,Imax2);
     end;
result:=0;
end;
{ passage en alim de courant }
{ INPUT: adresse, adresse GPIB                         }
{ OUTPUT: integer, code d'erreur                       }
{ REMARK: on coupe la sortie quand on switch dans ce mode }
Function SetToCurrentSource_CLET183(adresse:byte;channel:byte):integer;
begin
     SwitchOFF_CLET183(adresse);
     SetCourant_CLET183(adresse,channel,0);
     case channel of
          1:SetTension_CLET183(adresse,channel,Vmax1);
          2:SetTension_CLET183(adresse,channel,Vmax1);
          3:SetTension_CLET183(adresse,channel,Vmax2);
     end;
result:=0;
end;

end.
