unit ips12010;
{ unite de pilotage de l'alimentation IPS12010 Oxford     }
{ pour la bobine supra                                    }
{ you MUST FIRST MANUALLY UNCLAMP THE POWER SUPPLY        }
{ before using this unit                                  }
{ N.B. l'alimentation rpond toujours quelque chose       }
{ si on ne veut pas de rponse il faut faire prcder la commande par $ }
{ l'alim veut un CR  la fin de chaque commande           }
{ F. OTT, modifi le 21.01.2001                           }


interface

uses Dialogs, GPIB_CEC, Sysutils;

var
   FlagEnergizing:boolean; { flag indicating if the coil is beeing energised or not }

procedure delay(temps:double);                                    {ok}
function testEnergizing:boolean;
{ initialisation des alimentations }
Function Send_IPS12010(adresse:byte;s:string):string; {ok}
Function Initialize_IPS12010(adresse:byte):integer;               {ok}
Function SetSweepRate_IPS12010(adresse:byte;value:double):integer;{ok}
Function ExamineStatus_IPS12010(adresse:byte):string;             {ok}
Function ReadField_IPS12010(adresse:byte):double;                 {ok}
Function HeaterOn_IPS12010(adresse:byte):integer;                 {ok}
Function HeaterOff_IPS12010(adresse:byte):integer;                {ok}
Function SetField_IPS12010(adresse:byte;valeur:real):integer;

implementation

const
     SlowSpeedRate = 0.078; { applies even for the highest fields for the first ramp }
     FastSpeedRate = 0.5;   { Oxford max is 1T/min after initial ramp }
{ the slow speed rate should be used for the first field sweep of the }
{ coil after a colling down                                           }
{ the fast sweep rate is the normal sweep rate                        }
{ N.B. in principle, the sweep rate depends on the field magnitude    }
{      these settings are conservative                                }

{ pause de t secondes }
procedure delay(temps:double);
var t0,t:real;
begin
{ cette pause doit passer minuit et traiter les messages windows }
{ elle peut durer trs longtemps                                 }
    t0:=(time-int(time))*86400;  {temps en s}
    repeat
      t:=(time-int(time))*86400;
      if t<t0 then t:=t+86400;  {correction bug passage par minuit}
{      Application.processMessages; }
    until ((t-t0)>temps);
end;

function testEnergizing:boolean;
begin
     result:=FlagEnergizing;
end;

{ envoi d'une chaine  l'IPS        }
{ INPUT: adresse, adresse GPIB      }
{        s: chaine a envoyer        }
{        len: longueur de la chaine a lire }
{ OUTPUT: reponse de l'alim         }
{   !!! premier caractre seulement }
Function Send_IPS12010(adresse:byte;s:string):string;
var s1:string;
begin
     GPIBSend(adresse,s);
     { il y a un srieux problme de lecture }
     { si la procdure ne recoit pas ses 20 caracres elle timeout ...??? }
     { il manque un caractre de validation }
     GPIBread(adresse,s1,255);
     result:=s1;
end;

{ initialisation des alimentations }
Function Initialize_IPS12010(adresse:byte):integer; { ok }
var status:integer;
begin
     setoutputeos(13,0);
     setinputeos(13);
     { on passe en mode REMORE UNLOCKED }
     GPIBSend(adresse,'$C3');
     { protocol "normal" }
     { passage en "haute rsolution" = Q4 : 0.0001 A}
     GPIBSend(adresse,'Q0');
     { set mode } { DISPLAY Tesla; Mode Sweep; Speed slow }
     GPIBSend(adresse,'$M7');
     { on peut envisager de mettre le sweep en fast sinon c'est vraiment trs lent }
end;

{ INPUT: adresse GPIB                                    }
{        value: the field sweep rate in tesla per minute }
{ OUTPUT:                                                }
Function SetSweepRate_IPS12010(adresse:byte;value:double):integer; {ok}
var status:integer;
    s:string;
begin
     s:='$T'+FloatToStr(value);
     GPIBSend(adresse,s);
end;

{ INPUT: adresse, adresse GPIB                         }
{ OUTPUT: retour du champ persistent dans la bobine    }
{         en Teslas                                    }
Function ExamineStatus_IPS12010(adresse:byte):string;
var status:integer;
    s:string;
begin
     GPIBSend(adresse,'X'); { lecture du "persistent magnet field" }
     GPIBRead(adresse,s,255); { best 15 }
     { conversion de la chaine en T }
     result:=s;
end;

{ lecture du champ persistant dans l'aimant            }
{ INPUT: adresse, adresse GPIB                         }
{ OUTPUT: retour du champ persistent dans la bobine    }
{         en Teslas                                    }
Function ReadField_IPS12010(adresse:byte):double;    { OK }
var status:integer;
    s:string;
begin
     GPIBSend(adresse,'R18'); { lecture du "persistent magnet field" }
     GPIBRead(adresse,s,255); { best 8 }
     { conversion de la chaine en T }
     { il faut tronquer la premire lettre }
     result:=strTofloat(copy(s,2,7));
end;

{ INPUT: adresse GPIB                                  }
{ OUTPUT: on chauffe le switch pendant 15 secondes     }
{         si le courant magnet = courant PSU           }
{ REM : ne s'allume que si le courant de l'alim est gal au courant de la bobine }
Function HeaterOn_IPS12010(adresse:byte):integer;   {ok}
var status:integer;
    s:string;
begin
     GPIBSend(adresse,'$C3');
     GPIBSend(adresse,'$H1');
     { faire une pause de 15 secondes }
     delay(15); { valeurs Oxford }
end;

{ INPUT: adresse GPIB                                  }
{ OUTPUT: on chauffe le switch pendant 15 secondes     }
{         si le courant magnet = courant PSU           }
Function HeaterOff_IPS12010(adresse:byte):integer;   {ok}
var status:integer;
    s:string;
begin
     GPIBSend(adresse,'$C3');
     GPIBSend(adresse,'$H0');
     { faire une pause de 15 secondes }
     { pour etre sur que le switch est bien froid }
     delay(30); { valeurs Oxford }
end;

{ INPUT: adresse, adresse GPIB                         }
{        valeur, valeur du champcourant en AMPERES  -8<I<+8 }
{ OUTPUT: integer, code d'erreur                       }
Function SetField_IPS12010(adresse:byte;valeur:real):integer;
var s,s1:string;
    status,i:integer;
    l:word;
    aux:string;
begin
     FlagEnergizing:=true;
     s:='$J'+FloatToStr(valeur);
     GPIBSend(adresse,'$C3'); { on se remt en remote }
     delay(1);
     { on reva au setPoint prcdent; on fait confiance  l'alimentation pour garder le bon setPoint }
     { cad on suppose qu'il n'y a pas eu de bidouille sur l'alim                                     }
     GPIBSend(adresse,'$A1'); { to set point }
     delay(1);
     { on laisse le temps a l'alim d'aller au setPoint }
     repeat
     aux:=copy(ExamineStatus_IPS12010(adresse),12,1);
     until aux='0';
     delay(1);
     { on ouvre le switch          }
     HeaterOn_IPS12010(adresse);
     { changement de SetPoint      }
     GPIBSend(adresse,s);           { set traget field }
     delay(1);
     { N.B. l'alim va directos au set point parce qu'on est deja en mode A1 }
     GPIBSend(adresse,'$A1'); { to set point }
     delay(1);
     { il faut utiliser GetStatus }
     { la lecture du champ ne fonctionne pas tant que le switch n'est pas eteint }
     repeat
     aux:=copy(ExamineStatus_IPS12010(adresse),12,1);
     until aux='0';
     delay(1);
     { on ferme le switch          }
     HeaterOff_IPS12010(adresse);
     { on ramne l'alimentation  zro }
     GPIBSend(adresse,'$A2');  { to zro }
     FlagEnergizing:=false;
end;

initialization

FlagEnergizing := false;


end.
